<template>
  <div class="riskBox">
    <el-form ref="formRef" :model="state.formData" :rules="state.rules" class="register-form" label-position="top">
      <el-row :gutter="30">
        <el-col :span="6">
          <el-form-item prop="project.leader" label="项目负责人">
            <el-input
                v-model="state.formData.project.leader"
                size="large"
                placeholder="请选择项目负责人"
            >
              <template #append>
                <el-button :icon="Search" @click="openExperts('项目负责人')"/>
              </template>
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item prop="project.contactor" label="联系人">
            <el-input
                v-model="state.formData.project.contactor"
                size="large"
                placeholder="请选择联系人"
            >
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item prop="project.phone" label="联系电话">
            <el-input
                v-model="state.formData.project.phone"
                size="large"
                placeholder="请选择联系电话"
            >
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item label="传真">
            <el-input
                v-model="state.formData.project.fax"
                size="large"
                placeholder="请选择传真"
            >
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row :gutter="30">
        <el-col :span="6">
          <el-form-item prop="deliver" label="任务下达人">
            <el-input
                v-model="state.formData.deliver"
                size="large"
                placeholder="请选择任务下达人"
            >
              <template #append>
                <el-button :icon="Search" @click="openExperts('任务下达人')"/>
              </template>
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item prop="deliverDate" label="任务下达时间">
            <el-date-picker
                style="width: 100%"
                v-model="state.formData.deliverDate"
                type="date"
                value-format="YYYY-MM-DD 00:00:00"
                placeholder="选择日期"
                size="large"
            />
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <experts-list ref="expertsListRef" @getName="getSelected"></experts-list>
  </div>
</template>
<script setup>

import {defineEmits, onMounted, reactive, ref} from "vue";
import {ElMessage} from "element-plus";
import {Search} from '@element-plus/icons-vue'
import {addRisk, editRisk, getRiskDetail} from "@/api/projectManage/riskAnalysis";
import Cookies from "js-cookie"
import ExpertsList from "./expertsList";
const emit = defineEmits(["getNextStatus"]);

const state = reactive({
  formData: {
    id: '',
    deliver: '',
    deliverDate: '',
    project: {
      id: '',
      leader: '',
      contactor: '',
      phone: ''
    }
  },
  rules: {
    "project.leader": [{required: true, message: '请选择项目负责人', trigger: 'blur'}],
    "project.contactor": [{required: true, message: '请输入联系人', trigger: 'blur'}],
    "project.phone": [{required: true, message: '请输入联系电话', trigger: 'blur'}],
    deliverDate: [{required: true, message: '请选择任务下达时间', trigger: 'blur'}]
  },
  estimateTypeList: [],
  addressList: [],
  businessList: [],
  tableData: [
    {
      id: '1',
      content: '评价项目是否在本机构资质业务范围内',
      status: 1
    },
    {
      id: '2',
      content: '评价人员专业构成是否满足评价项目需要',
      status: 1
    },
    {
      id: '3',
      content: '是否需要聘请相关专业的技术专家',
      status: 1
    },
    {
      id: '4',
      content: '是否能在约定的时间内完成评价报告',
      status: 1
    },
    {
      id: '5',
      content: '评价费用是否在本机构所接受的范围内',
      status: 1
    },
    {
      id: '6',
      content: '项目的可行性（风险分析结论）',
      status: 1
    },
  ]
})
const props = {
  expandTrigger: 'hover',
  value: 'name',
  label: 'name'
}
const isAmin = ref(false)
const formRef = ref()
const expertsListRef = ref()
onMounted(() => {
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  if(userInfo.identity === 0){
    isAmin.value = true;
  }
})

const riskOpen = async (type,val) => {
  console.log("type",type,val)
  if(type === 'detail' || type === 'edit' ){
    const res = await getRiskDetail({projectId: val});
    if(res.code == 200){
      state.formData = res.data;
      state.formData.project.business = parseInt(res.data.project.business);
      state.formData.project.area = [res.data.project.province,res.data.project.city];
      state.tableData[0].status = res.data.isInBusiness ? 1 : 0;
      state.tableData[1].status = res.data.isSatisfyNeed ? 1 : 0;
      state.tableData[2].status = res.data.isNeedExpert ? 1 : 0;
      state.tableData[3].status = res.data.isFinishReport ? 1 : 0;
      state.tableData[4].status = res.data.isAcceptChargess ? 1 : 0;
      state.tableData[5].status = res.data.isFeasibility ? 1 : 0;
    }else {
      ElMessage.warning(res.message)
    }
  }
  if(type === 'add' || type === 'clickEdit') {
    const valid = await formRef.value.validate();
    if(valid){
      if (isAmin.value) {
        ElMessage.warning("当前用户暂无权限");
        return;
      }
      if(type === 'add'){
        const {id, ...data} = JSON.parse(JSON.stringify(state.formData))
        delete data.project.area;
        delete data.project.id;
        data.isInBusiness = state.tableData[0].status === 1;
        data.isSatisfyNeed = state.tableData[1].status === 1;
        data.isNeedExpert = state.tableData[2].status === 1;
        data.isFinishReport = state.tableData[3].status === 1;
        data.isAcceptChargess = state.tableData[4].status === 1;
        data.isFeasibility = state.tableData[5].status === 1;
        console.log('data', data)
        const res = await addRisk(data);
        if (res.code == 200) {
          ElMessage.success('保存成功')
          formRef.value.clearValidate();
          emit('getNextStatus', res.data);

        } else {
          ElMessage.warning(res.message)
        }
      }else if(type === 'clickEdit'){
        const { ...data} = JSON.parse(JSON.stringify(state.formData))
        delete data.project.area;
        data.isInBusiness = state.tableData[0].status === 1;
        data.isSatisfyNeed = state.tableData[1].status === 1;
        data.isNeedExpert = state.tableData[2].status === 1;
        data.isFinishReport = state.tableData[3].status === 1;
        data.isAcceptChargess = state.tableData[4].status === 1;
        data.isFeasibility = state.tableData[5].status === 1;
        const res = await editRisk(data);
        if (res.code == 200) {
          ElMessage.success('变更成功')
          formRef.value.clearValidate();
          // emit('getNextStatus', data.project.id);
        } else {
          ElMessage.warning(res.message)
        }
      }
    }
  }
}

const openExperts = (type) =>{
  expertsListRef.value.openDialog(type)
}

const getSelected = (type,obj)=>{
  if(type == '项目负责人'){
    state.formData.project.leader = obj.name
  }
  if(type == '任务下达人'){
    state.formData.deliver = obj.name
  }
}

defineExpose({
  riskOpen
});


</script>
<style scoped lang="scss">
.riskBox{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
}

</style>
